@@ -10,7 +10,7 @@ use parent 'Type::Tiny::Signatures';
 
 our @DEFAULTS = @Type::Tiny::Signatures::DEFAULTS = 'Data::Object::Library';
 
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 1;
 
@@ -26,7 +26,7 @@ Data::Object::Signatures - Data::Object Method/Function Signatures for Perl 5
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -34,10 +34,9 @@ version 0.02
 
 =head1 DESCRIPTION
 
-Data::Object::Signatures is a subclass of L<Type::Tiny::Signatures> and derives
-its functionality to provide method and function signatures with support for
-all the standard L<Type::Tiny> type constraints, as well as a few additional
-type constraints provided by L<Data::Object::Library>.
+Data::Object::Signatures is a subclass of L<Type::Tiny::Signatures> providing
+method and function signatures supporting all the type constraints provided by
+L<Data::Object::Library>.
 
 =head1 AUTHOR
 
